{#media_dlg.title}

- {#media_dlg.general}
- {#media_dlg.advanced}

{#media_dlg.general}
{#media_dlg.type}
{#media_dlg.file}
{#media_dlg.list}
{#media_dlg.size}
x px

{#media_dlg.constrain_proportions}

{#media_dlg.preview}
{#media_dlg.advanced}
{#media_dlg.id}
{#media_dlg.name}
{#media_dlg.align}
{#media_dlg.bgcolor}
{#media_dlg.vspace}
{#media_dlg.hspace}

## {#media_dlg.flash_options}

{#media_dlg.flash_options}
{#media_dlg.quality}
{#media_dlg.scale}
{#media_dlg.wmode}
{#media_dlg.salign}
{#media_dlg.play}
{#media_dlg.loop}
{#media_dlg.menu}
{#media_dlg.liveconnect}
{#media_dlg.base}
{#media_dlg.flashvars}

## {#media_dlg.flv_options}

{#media_dlg.flv_options}
{#media_dlg.flv_scalemode}
{#media_dlg.flv_buffer}
{#media_dlg.flv_startimage}
{#media_dlg.flv_starttime}
{#media_dlg.flv_defaultvolume}
{#media_dlg.flv_hiddengui}
{#media_dlg.flv_autostart}
{#media_dlg.flv_loop}
{#media_dlg.flv_showscalemodes}
{#media_dlg.flv_smoothvideo}
{#media_dlg.flv_jscallback}

## {#media_dlg.qt_options}

{#media_dlg.qt_options}
{#media_dlg.loop}
{#media_dlg.play}
{#media_dlg.cache}
{#media_dlg.controller}
{#media_dlg.correction}
{#media_dlg.enablejavascript}
{#media_dlg.kioskmode}
{#media_dlg.autohref}
{#media_dlg.playeveryframe}
{#media_dlg.targetcache}
{#media_dlg.scale}
{#media_dlg.starttime}
{#media_dlg.endtime}
{#media_dlg.target}
{#media_dlg.href}
{#media_dlg.qtsrcchokespeed}
{#media_dlg.volume}
{#media_dlg.qtsrc}
lolo
{#media_dlg.wmp_options}
{#media_dlg.wmp_options}
{#media_dlg.autostart}
{#media_dlg.enabled}
{#media_dlg.menu}
{#media_dlg.fullscreen}
{#media_dlg.invokeurls}
{#media_dlg.mute}
{#media_dlg.stretchtofit}
{#media_dlg.windowlessvideo}
{#media_dlg.balance}
{#media_dlg.baseurl}
{#media_dlg.captioningid}
{#media_dlg.currentmarker}
{#media_dlg.currentposition}
{#media_dlg.defaultframe}
{#media_dlg.playcount}
{#media_dlg.rate}
{#media_dlg.uimode}
{#media_dlg.volume}
{#media_dlg.rmp_options}

| {#media_dlg.autostart}
| {#media_dlg.loop}
| {#media_dlg.autogotourl}
| {#media_dlg.center}
| {#media_dlg.imagestatus}
| {#media_dlg.maintainaspect}
| {#media_dlg.nojava}
| {#media_dlg.prefetch}
| {#media_dlg.shuffle}
{#media_dlg.console} |  | {#media_dlg.controls} |
{#media_dlg.numloop} |  | {#media_dlg.scriptcallbacks} |

{#media_dlg.shockwave_options}

{#media_dlg.swstretchstyle} |  | {#media_dlg.volume} |
{#media_dlg.swstretchhalign} |  | {#media_dlg.swstretchvalign} |
| {#media_dlg.autostart}
| {#media_dlg.sound}
| {#media_dlg.liveconnect}
| {#media_dlg.progress}